import sys

# from . import cl_util

print(sys.argv)

if True or not sys.argv[0]:
    from . import cl_util
    # from cl_util import check_file_system
    cl_util.check_file_system()
    from .feature.decorators import preview, register, deregister, dropper, selector
    from .feature.stl import *
    from .feature import stl
    from .feature.storage import feature_list as features
    from .validation.experiment import experiment_list as experiments

    __all__ = [
        'feature',
        'features',
        'validation',
        'experiments',
        'stl',
        'zoo',
        'model',
        'pipeline',
        'storage',
        'cli'
    ]

    with open("VERSION", 'r') as f:
        __version__ = f"0.0.{int(f.read().strip()) + 1}"


import argparse
import sys
from .file_system import build_file_system, check_file_system


def run():
    parser = argparse.ArgumentParser()
    subparsers = parser.add_subparsers(dest="subcommand",
                                       title='subcommands',
                                       description='valid subcommands',
                                       help='Use init to initialize kts project inside of this folder.')
    subparsers.add_parser('init')
    args = parser.parse_args(sys.argv[1:])
    if args.subcommand == 'init':
        build_file_system()
    else:
        parser.print_help()



import os
import shutil
from .. import config

def list_files(startpath):
    for root, dirs, files in os.walk(startpath):
        level = root.replace(startpath, '').count(os.sep)
        indent = ' ' * 4 * level
        print('{}{}/'.format(indent, os.path.basename(root)))
        subindent = ' ' * 4 * (level + 1)
        for f in files:
            print('{}{}'.format(subindent, f))


def check_existance(paths):
    """
    Checks necessity of clearing the folder.
    :param paths: list of directories
    :return: True if at least one directory exists, False otherwise
    """
    for path in paths:
        if os.path.isdir(path):
            return True
    return False


def check_structure(paths):
    for path in paths:
        if not os.path.isdir(path):
            return False
    return True


def clear_all():
    """
    Clears current folder.
    :return:
    """
    folder = './'
    for the_file in os.listdir(folder):
        file_path = os.path.join(folder, the_file)
        try:
            if os.path.isfile(file_path):
                os.remove(file_path)
            elif os.path.isdir(file_path):
                shutil.rmtree(file_path)
        except Exception as e:
            print(e)


def build_file_system(force=False):
    """
    Builds directory structure for correct running kts.
    :param force: True or False (without confirmation or not)
    :return:
    """
    paths = ['./input', './notebooks', './storage/info', './storage/sources', './output']

    if check_existance(paths):
        if force:
            clear_all()

        list_files('./')
        print('Do you want to clear existing kts file system? [y/N]')
        try:
            answer = str(input())
            if answer.lower() == 'y' or answer.lower() == 'yes':
                clear_all()
        except Exception as e:
            raise TypeError('Invalid answer')

    print('Do you want to build the file system? [y/N]')
    try:
        answer = str(input())
        if answer.lower() == 'y' or answer.lower() == 'yes':
            for path in paths:
                if not os.path.isdir(path):
                    os.makedirs(path)
    except Exception as e:
        raise TypeError('Invalid answer')

IMPORT_ERROR_MESSAGE = """
This directory doesn't look like kts project.
Use `kts init` to initialize a project. You can't use kts without its file system.
This error could also be raised by importing kts from a directory of existing project other than /notebooks.
"""

def check_file_system():
    paths = ['../input', '../notebooks', '../storage/info', '../storage/sources', '../output']

    if check_structure(paths):
        return

    raise ImportError(IMPORT_ERROR_MESSAGE)
